function robotimpe
close all;


% set number of iterations
N=100;

% set integration interval
tspan = [0, 2*pi];

% compute stepsize
h=tspan(2)/N;

% set initial value
y0=[0;0;0;pi/3;-pi/3;0;0];

%arm end position function
g=@(theta) sum([cos(theta)';sin(theta)'],2);

%arm's path function
gamma=@(t) [4+4/5*sin(t).^3;...
     13/16*cos(t)-5/16*cos(2*t)-1/8*cos(3*t)-1/16*cos(4*t)-5/16];


% right hand side
Dc=@(theta) [-sin(theta)';cos(theta)'];

F = @(t,y) [-h*Dc(y(1:5))'*y(6:7);...
              g(y(1:5))-gamma(t)];

%derivation of the right hand side for Newton step
DF=@(y) vertcat([eye(5), zeros(5,2)] +h*[diag(y(6)*cos(y(1:5))+y(7)*sin(y(1:5))),sin(y(1:5)),-cos(y(1:5))],...
    [Dc(y(1:5)),zeros(2,2)]) ;

%Compute the evolution of y as well as the approximated path
% and its distance to the exact path
y=y0;
err=zeros(1,N);
approx_path=zeros(2,N+1);
approx_path(:,1)=g(y0(1:5));
for i=1:N
    %compute the new value by a Newton step
    y=y-DF(y)\F(i*h,y);
    %compute approximated path
    approx_path(:,i+1)=g(y(1:5));
% and its distance to the exact path
    err(i)=norm(g(y(1:5))-gamma(h*i));
    
end
% compute the path's exact path
exact_path=gamma(0:h:2*pi);

% plot of the exact and approximated path
figure;
plot(exact_path(1,:), exact_path(2,:),'b',approx_path(1,:),approx_path(2,:),'ro');
xlim([3 5]);
ylim([-1.6 0.6]);
legend('exact path','approximated path','Location','SouthEast');



% Plot the distance between the paths
figure;
plot(h:h:2*pi,err,'*-');
xlabel('time');
ylabel('error');
title('distance between exact and approximated solution');

