function robotsolve2
close all;

% set integration interval
tspan = [0, 2*pi];

% initial value
y0=[0;0;0;pi/3;-pi/3;0;0];

%arm end position function
g=@(theta) sum([cos(theta)';sin(theta)'],2);

%path function of the arm
gamma=@(t) [4+4/5*sin(t).^3;...
     13/16*cos(t)-5/16*cos(2*t)-1/8*cos(3*t)-1/16*cos(4*t)-5/16];

% right hand side
Dc=@(theta) [-sin(theta)';cos(theta)'];

gammadot=@(t) [ 12/5*sin(t).^2*cos(t);...
                 -13/16*sin(t)+5/8*sin(2*t)+3/8*sin(3*t)+1/4*sin(4*t)];

fun = @(t,y) [Dc(y(1:5))'*y(6:7);...
              Dc(y(1:5))*Dc(y(1:5))'*y(6:7)-gammadot(t)];
		  
% construct mass matrix
M = vertcat([eye(5),zeros(5,2)],zeros(2,7));

% call up ode23t
opts = odeset('Mass', M);
[t,y] = ode23t(fun, tspan, y0, opts);

%compute the arm's exact path
exact_path=gamma(t');

%compute the approximated path as well as the
%distance between the approximated and the exact path
approx_path=zeros(2,length(t));
err=zeros(1,length(t));
for i=1:length(t)
    approx_path(:,i)=g(y(i,1:5)');
    err(i)=norm(g(y(i,1:5)')-gamma(t(i)));
end


% plot of the exact and approximated path
figure;
plot(exact_path(1,:), exact_path(2,:),'b',approx_path(1,:),approx_path(2,:),'ro'); 
xlim([3 5]);
ylim([-1.6 0.6]);
legend('exact path','approximated path','Location','SouthEast');

% Plot the distance between the paths
figure;
plot(t,err,'*-');
xlabel('time');
ylabel('error');
title('distance between exact and approximated solution');